@@ -8,12 +8,14 @@
 #pragma once
 
 #include <QAbstractProxyModel>
+#include <qqmlregistration.h>
 
 #include "PagesModel.h"
 
 class PageSortModel : public QAbstractProxyModel
 {
     Q_OBJECT
+    QML_ELEMENT
 
 public:
     enum Roles {
@@ -41,7 +43,7 @@ public:
     Q_INVOKABLE void applyChangesToSourceModel() const;
 
 private:
-    QVector<int> m_rowMapping;
-    QVector<bool> m_hiddenProxy;
-    QVector<bool> m_removeFiles;
+    QList<int> m_rowMapping;
+    QList<bool> m_hiddenProxy;
+    QList<bool> m_removeFiles;
 };
